#[non_exhaustive]pub enum Event<'a> {
IconSize {
size: i32,
},
Done,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
IconSize
describes a supported & preferred icon size
This event indicates an icon size the compositor prefers to be available if the client has scalable icons and can render to any size.
When the ‘xdg_toplevel_icon_manager_v1’ object is created, the compositor may send one or more ‘icon_size’ events to describe the list of preferred icon sizes. If the compositor has no size preference, it may not send any ‘icon_size’ event, and it is up to the client to decide a suitable icon size.
A sequence of ‘icon_size’ events must be finished with a ‘done’ event. If the compositor has no size preferences, it must still send the ‘done’ event, without any preceding ‘icon_size’ events.
Done
all information has been sent
This event is sent after all ‘icon_size’ events have been sent.